@@ -37,6 +37,7 @@ import SessionStorageService, { SessionStorageKey } from '@/services/session-sto
 import { RootState } from '@/store';
 import { selectBranding } from '@/store/Branding';
 import { factoryResolverActionCreators, selectFactoryResolver } from '@/store/FactoryResolver';
+import { FACTORY_RESOLVER_NOT_FOUND_ERROR_MESSAGE } from '@/store/Workspaces/devWorkspaces/actions/actionCreators/const';
 import { selectAllWorkspaces } from '@/store/Workspaces/selectors';
 
 export class ApplyingDevfileError extends Error {
@@ -87,6 +88,10 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
   }
 
   public shouldComponentUpdate(nextProps: Props, nextState: State): boolean {
+    if (this.state.name !== nextState.name) {
+      return true;
+    }
+
     // active step changed
     if (this.props.distance !== nextProps.distance) {
       return true;
@@ -200,10 +205,9 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
       return true;
     }
 
-    let resolveDone = false;
     try {
       // start resolving the devfile
-      resolveDone = await this.resolveDevfile(sourceUrl);
+      await this.resolveDevfile(sourceUrl);
     } catch (e) {
       const errorMessage = common.helpers.errors.getMessage(e);
       // check if it is a scheme validation error
@@ -212,8 +216,7 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
       }
       if (
         errorMessage === 'Failed to fetch devfile' ||
-        errorMessage ===
-          'Cannot build factory with any of the provided parameters. Please check parameters correctness, and resend query.' ||
+        errorMessage === FACTORY_RESOLVER_NOT_FOUND_ERROR_MESSAGE ||
         errorMessage.startsWith('Could not reach devfile')
       ) {
         this.setState({ useDefaultDevfile: true });
@@ -221,9 +224,6 @@ class CreatingStepFetchDevfile extends ProgressStep<Props, State> {
       }
       throw e;
     }
-    if (!resolveDone) {
-      return false;
-    }
 
     // wait for the devfile resolving to complete
     return false;
