@@ -25,6 +25,7 @@ import {
   selectRegistriesErrors,
   selectRegistriesMetadata,
 } from '@/store/DevfileRegistries/selectors';
+import { ServerConfigState } from '@/store/ServerConfig';
 
 jest.mock('js-yaml', () => ({
   load: jest.fn(),
@@ -41,6 +42,13 @@ describe('DevfileRegistries, selectors', () => {
 
   beforeEach(() => {
     mockState = {
+      dwServerConfig: {
+        config: {
+          defaults: {
+            pvcStrategy: 'per-user',
+          },
+        },
+      } as Partial<ServerConfigState>,
       devfileRegistries: {
         registries: {
           'https://registry1.com': {
@@ -59,7 +67,7 @@ describe('DevfileRegistries, selectors', () => {
                 displayName: 'Devfile 2',
                 description: 'Description 2',
                 links: { v2: 'https://registry2.com/devfile2' },
-                tags: ['Empty'],
+                tags: ['tag2', 'Empty'],
               } as che.DevfileMetaData,
             ],
             error: 'Error message',
@@ -105,7 +113,7 @@ describe('DevfileRegistries, selectors', () => {
         displayName: 'Devfile 2',
         description: 'Description 2',
         links: { v2: 'https://registry2.com/devfile2' },
-        tags: ['Empty'],
+        tags: ['tag2', 'Empty'],
         registry: 'https://registry2.com',
       },
     ]);
@@ -132,8 +140,11 @@ describe('DevfileRegistries, selectors', () => {
   });
 
   describe('selectMetadataFiltered', () => {
-    it('should select metadata filtered by filter value', () => {
+    it('should select metadata filtered by filter value by displayName', () => {
+      mockState.devfileRegistries.filter = 'Devfile 1';
+
       const result = selectMetadataFiltered(mockState);
+
       expect(result).toEqual([
         {
           displayName: 'Devfile 1',
@@ -145,6 +156,54 @@ describe('DevfileRegistries, selectors', () => {
       ]);
     });
 
+    it('should select metadata filtered by filter value by description', () => {
+      mockState.devfileRegistries.filter = 'Description 1';
+
+      const result = selectMetadataFiltered(mockState);
+
+      expect(result).toEqual([
+        {
+          displayName: 'Devfile 1',
+          description: 'Description 1',
+          links: { v2: 'https://registry1.com/devfile1' },
+          tags: ['tag1'],
+          registry: 'https://registry1.com',
+        },
+      ]);
+    });
+
+    it('should select metadata filtered by filter value by tags', () => {
+      mockState.devfileRegistries.filter = 'Empty';
+
+      const result = selectMetadataFiltered(mockState);
+
+      expect(result).toEqual([
+        {
+          displayName: 'Devfile 2',
+          description: 'Description 2',
+          links: { v2: 'https://registry2.com/devfile2' },
+          tags: ['tag2', 'Empty'],
+          registry: 'https://registry2.com',
+        },
+      ]);
+    });
+
+    it('should select metadata filtered by filter value by link', () => {
+      mockState.devfileRegistries.filter = 'registry2.com';
+
+      const result = selectMetadataFiltered(mockState);
+
+      expect(result).toEqual([
+        {
+          displayName: 'Devfile 2',
+          description: 'Description 2',
+          links: { v2: 'https://registry2.com/devfile2' },
+          tags: ['tag2', 'Empty'],
+          registry: 'https://registry2.com',
+        },
+      ]);
+    });
+
     it('should select all metadata if filter value is empty', () => {
       const mockStateWithoutFilterValue = {
         ...mockState,
@@ -167,7 +226,7 @@ describe('DevfileRegistries, selectors', () => {
           displayName: 'Devfile 2',
           description: 'Description 2',
           links: { v2: 'https://registry2.com/devfile2' },
-          tags: ['Empty'],
+          tags: ['tag2', 'Empty'],
           registry: 'https://registry2.com',
         },
       ]);
@@ -180,7 +239,8 @@ describe('DevfileRegistries, selectors', () => {
   });
 
   describe('selectDefaultDevfile', () => {
-    it('should select default devfile', () => {
+    it('should select devfile without storage-type', () => {
+      delete mockState.dwServerConfig.config.defaults.pvcStrategy;
       const mockDevfile = {
         schemaVersion: '2.2.0',
         metadata: {
@@ -204,6 +264,59 @@ describe('DevfileRegistries, selectors', () => {
         }),
       );
     });
+    it('should select devfile with default storage-type', () => {
+      const mockDevfile = {
+        schemaVersion: '2.2.0',
+        metadata: {
+          name: 'empty',
+        },
+      };
+      const mockDevfileStr = 'schemaVersion: 2.2.0\nmetadata:\n  name: empty\n';
+
+      (load as jest.Mock).mockReturnValue(mockDevfile);
+      (dump as jest.Mock).mockReturnValue(mockDevfileStr);
+
+      const result = selectDefaultDevfile(mockState);
+      expect(result).toEqual(
+        Object.assign({}, mockDevfile, {
+          attributes: {
+            'controller.devfile.io/storage-type': 'per-user',
+            'dw.metadata.annotations': {
+              'che.eclipse.org/devfile': mockDevfileStr,
+            },
+          },
+          components: [],
+        }),
+      );
+    });
+    it('should select devfile with storage-type', () => {
+      const mockDevfile = {
+        schemaVersion: '2.2.0',
+        metadata: {
+          name: 'empty',
+        },
+        attributes: {
+          'controller.devfile.io/storage-type': 'per-workspace',
+        },
+      };
+      const mockDevfileStr = 'schemaVersion: 2.2.0\nmetadata:\n  name: empty\n';
+
+      (load as jest.Mock).mockReturnValue(mockDevfile);
+      (dump as jest.Mock).mockReturnValue(mockDevfileStr);
+
+      const result = selectDefaultDevfile(mockState);
+      expect(result).toEqual(
+        Object.assign({}, mockDevfile, {
+          attributes: {
+            'controller.devfile.io/storage-type': 'per-workspace',
+            'dw.metadata.annotations': {
+              'che.eclipse.org/devfile': mockDevfileStr,
+            },
+          },
+          components: [],
+        }),
+      );
+    });
 
     it('should return undefined if the empty workspace URL is not found', () => {
       const mockStateWithoutEmptyWorkspaceUrl = {
