@@ -13,6 +13,7 @@
 import common, { api } from '@eclipse-che/common';
 import { createAction } from '@reduxjs/toolkit';
 
+import { getAxiosInstance } from '@/services/axios-wrapper/getAxiosInstance';
 import * as ServerConfigApi from '@/services/backend-client/serverConfigApi';
 import { AppThunk } from '@/store';
 import { verifyAuthorized } from '@/store/SanityCheck';
@@ -24,14 +25,17 @@ export const serverConfigErrorAction = createAction<string>('serverConfig/error'
 export const actionCreators = {
   requestServerConfig: (): AppThunk => async (dispatch, getState) => {
     try {
-      await verifyAuthorized(dispatch, getState);
-
       dispatch(serverConfigRequestAction());
 
       const config = await ServerConfigApi.fetchServerConfig();
 
+      if (config?.timeouts?.axiosRequestTimeout) {
+        getAxiosInstance().defaults.timeout = config.timeouts.axiosRequestTimeout;
+      }
+
       dispatch(serverConfigReceiveAction(config));
     } catch (e) {
+      await verifyAuthorized(dispatch, getState);
       const error = common.helpers.errors.getMessage(e);
       dispatch(serverConfigErrorAction(error));
       throw new Error(`Failed to fetch workspace defaults. ${error}`);
