@@ -19,11 +19,14 @@ import getRandomString from '@/services/helpers/random';
 import { DevWorkspaceStatus } from '@/services/helpers/types';
 
 export class DevWorkspaceBuilder {
+  private name = 'dev-wksp-' + getRandomString(4);
   private workspace: any = {
     kind: 'DevWorkspace',
     apiVersion: 'workspace.devfile.io/v1alpha2',
     metadata: {
-      annotations: {},
+      annotations: {
+        'che.eclipse.org/devfile': `schemaVersion: 2.2.0\nmetadata:\n generateName: dev-wksp\n`,
+      },
       labels: {},
       name: 'dev-wksp-' + getRandomString(4),
       namespace: '',
